import simple_gpg.gpg
import sys

sys.setrecursionlimit(1100)

def main():
    simple_gpg.gpg.main()

if __name__ == '__main__' :
    main()
